<?php

class VDEVShopifyCollection extends VDEVShopify
{
    public $response = [];
    
    public function getCollections($custom = true, $limit = 20)
    {
        $callURI = '/admin/api/2021-10/' . ($custom ? 'custom_' : '' ) . 'collections.json';
        $call = $this->call(
            $callURI, [
                'limit' => (int)$limit
            ],
            'GET'
        );
        
        return $this->getCallResponse($call, ($custom ? 'custom_' : '' ) . 'collections');
    }

    public function getCollectionById($collectionId, $custom = true)
    {
        $callURI = '/admin/api/2021-10/' . ($custom ? 'custom_' : '') . 'collections/' . (int)$collectionId . '.json';
        $call = $this->call($callURI, [], 'GET');
        
        return $this->getCallResponse($call, 'collection');
    }
    
    public function createCollection($collection, $custom = true)
    {
        $callURI = '/admin/api/2022-10/' . ($custom ? 'custom_' : '') . 'collections.json';
        $callQueries = [
            ($custom ? 'custom_' : '') . 'collection' => $collection
        ];
        
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, ($custom ? 'custom_' : '') . 'collection');
    }
    
    public function updateCollection($collection, $newCollection, $custom = true) {
        $callURI = '/admin/api/2022-10/' . ($custom ? 'custom_' : '') . 'collections/' . (int)$collection['id'] . '.json';
        $callQueries = [
            (($custom ? 'custom_' : '') . 'collection') => $newCollection
        ];
        
        $call = $this->call($callURI, $callQueries, 'PUT');
        
        return $this->getCallResponse($call, ($custom ? 'custom_' : '') . 'collection');
    }
    
    public function assignProductsToCustomCollection($collection, $custom = true)
    {
        $callURI = '/admin/api/2022-10/' . ($custom ? 'custom_' : '') . 'collections/' . (int)$collection['id'] . '.json';
        $callQueries = [
            'custom_collection' => $collection
        ];
        
        $call = $this->call($callURI, $callQueries, 'PUT');
        
        return $this->getCallResponse($call, 'collection');  
    }
    
    public function getCollectionMetafields($collection, $namespace = null, $key = null) 
    {
        $callURI = '/admin/api/2022-10/metafields.json';
        $callQueries = [
            'metafield' => [
                'owner_id' => (int)$collection['id'],
                'owner_resource' => 'collection'
            ]
        ];
        
        $call = $this->call($callURI, $callQueries, 'GET');
        
        if ($namespace && $key) {
            $metafields = $this->getCallResponse($call, 'metafields');
            
            if (!empty($metafields)) {
                
                foreach ($metafields as $metafield) {
                    
                    if ($metafield['namespace'] == $namespace && $metafield['key'] == $key) {
                        return $metafield['value'];
                    }
                }
            } 
            
            return null;
        
        } else {
            return $this->getCallResponse($call, 'metafields');  
        }
    }
    
    public function updateCollectionMetafield($collection, $metafield, $custom = true) 
    {
        $callURI = '/admin/api/2022-10/' . ($custom ? 'custom_' : '') . 'collections/' . (int)$collection['id'] . '/metafields.json';
        $callQueries = [
            'metafield' => $metafield
        ];
        
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, 'metafield');  
    }
    
    /*** NEW ***/
    public function getAll($parameters = [], $type = 'custom', $pagination = false)
    {
        $callURI = '/admin/api/2022-04/' . (!empty($type) ? $type . '_' : '')  . 'collections.json';
        $call = $this->call($callURI, $parameters, 'GET');
        
        return $this->getCallResponse($call, (!empty($type) ? $type . '_' : '')  . 'collections', $pagination);
    }
    
    public function add($collection, $type = 'custom')
    {
        $callURI = '/admin/api/2022-10/' . (!empty($type) ? $type . '_' : '') . 'collections.json';
        $callQueries = [
            (!empty($type) ? $type . '_' : '') . 'collection' => $collection
        ];
        
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, (!empty($type) ? $type . '_' : '') . 'collection');
    }
    
    public function setById($id, $collection, $type = 'custom')
    {
        $callURI = '/admin/api/2022-10/' . (!empty($type) ? $type . '_' : '') . 'collections/' . (int)$id . '.json';
        $callQueries = [
            ((!empty($type) ? $type . '_' : '') . 'collection') => $collection
        ];
        
        $call = $this->call($callURI, $callQueries, 'PUT');
        
        return $this->getCallResponse($call, (!empty($type) ? $type . '_' : '') . 'collection');
    }
    
    public function getMetafieldsById($id, $namespace = null, $key = null) 
    {
        $callURI = '/admin/api/2022-10/metafields.json';
        $callQueries = [
            'metafield' => [
                'owner_id' => (int)$id,
                'owner_resource' => 'collection'
            ]
        ];
        
        $call = $this->call($callURI, $callQueries, 'GET');
        
        if ($namespace && $key) {
            $metafields = $this->getCallResponse($call, 'metafields');
            
            if (!empty($metafields)) {
                
                foreach ($metafields as $metafield) {
                    
                    if (!empty($metafield['namespace']) && !empty($metafield['namespace'])) {
                        
                        if ($metafield['namespace'] == $namespace && $metafield['key'] == $key) {
                            return $metafield['value'];
                        }
                    }
                }
            } 
            
            return null;
        
        } else {
            return $this->getCallResponse($call, 'metafields');  
        }
    }
    
    public function setMetafieldById($id, $metafield) 
    {
        $callURI = '/admin/api/2022-10/collections/' . (int)$id . '/metafields.json';
        $callQueries = [
            'metafield' => $metafield
        ];
        $call = $this->call($callURI, $callQueries, 'POST');
        
        return $this->getCallResponse($call, 'metafield');  
    }
    /*** /NEW ***/
}